cp_block_index

Function cp_block_index 

pub fn cp_block_index(cp_num: u64) -> i64
The block a checkpoint belongs to. Checkpoints in a block share the same bloom filter and the block id is used as the seed for the blocked bloom filter hash functions.